==> v8.3.zip: ru_twords_ru_tw/bible/other/oath.md <==
# клятва, клясться, божиться

## Определение:

Клятва — это нерушимое обещание. Давший клятву обязуется исполнить обещанное.

* В Библии слово “клясться” употребляется в значении “произнести клятву”.
* Словосочетание “клясться кем-то или чем-то” означает использование чьего-либо имени или какого-либо названия для придания клятве большей значимости.
* Когда в клятве упоминается Бог, иногда говорят: “божиться”. Вполне допустимо употреблять эти слова вместе: “клясться и божиться”.
* Авраам и Авимелех дали клятву друг другу, когда заключали соглашение о пользовании колодцем.
* Авраам взял со своего слуги клятву, что тот найдёт жену для Исаака из рода Авраама.
* Бог, когда давал Своему народу обещания, клялся Собой.
* В современном русском языке слово “клясть” может употребляться в негативном значении: “проклинать”, “использовать нецензурную брань”.

## Варианты перевода:

* В зависимости от контекста слово “клятва” можно перевести как “обещание”, “торжественный обет”.
* Глагол “клясться” можно перевести как “обещать”, “ручаться”, “брать обязанность что-либо сделать”.
* Фразу “клясться кем-то” можно заменить фразой “поручиться чьим-либо именем”.
* Убедитесь, что слова “клясться” и “божиться” не употреблены в значении “проклинать”.

(См. также: [Авимелех](../names/abimelech.md), [завет](../kt/covenant.md), [обет](../kt/vow.md))

## Ссылки на библейский текст:

* [Быт. 21:22-24](rc://*/tn/help/gen/21/22)
* [Быт. 24:1-4](rc://*/tn/help/gen/24/01)
* [Быт. 31:51-53](rc://*/tn/help/gen/31/51)
* [Быт. 47:29-31](rc://*/tn/help/gen/47/29)
* [Лк. 1:72-75](rc://*/tn/help/luk/01/72)
* [Мк. 6:26-29](rc://*/tn/help/mrk/06/26)
* [Мф. 5:36-37](rc://*/tn/help/mat/05/36)
* [Мф. 14:6-7](rc://*/tn/help/mat/14/06)
* [Мф. 26:71-72](rc://*/tn/help/mat/26/71)

## Данные о слове:

* Номера Стронга: H422, H423, H3027, H5375, H7621, H7650, G332, G3660, G3727, G3728

==> v9.2.zip: ru_twords_ru_tw/bible/other/oath.md <==
# клятва, клясться, божиться

## Определение:

Клятва — это нерушимое обещание. Давший клятву обязуется исполнить обещанное.

* В Библии слово “клясться” употребляется в значении “произнести клятву”.
* Словосочетание “клясться кем-то или чем-то” означает использование чьего-либо имени или какого-либо названия для придания клятве большей значимости.
* Когда в клятве упоминается Бог, иногда говорят: “божиться”. Вполне допустимо употреблять эти слова вместе: “клясться и божиться”.
* Авраам и Авимелех дали клятву друг другу, когда заключали соглашение о пользовании колодцем.
* Авраам взял со своего слуги клятву, что тот найдёт жену для Исаака из рода Авраама.
* Бог, когда давал Своему народу обещания, клялся Собой.
* В современном русском языке слово “клясть” может употребляться в негативном значении: “проклинать”, “использовать нецензурную брань”.

## Варианты перевода:

* В зависимости от контекста слово “клятва” можно перевести как “обещание”, “торжественный обет”.
* Глагол “клясться” можно перевести как “обещать”, “ручаться”, “брать обязанность что-либо сделать”.
* Фразу “клясться кем-то” можно заменить фразой “поручиться чьим-либо именем”.
* Убедитесь, что слова “клясться” и “божиться” не употреблены в значении “проклинать”. 

(См. также: [Авимелех](../names/abimelech.md), [завет](../kt/covenant.md), [обет](../kt/vow.md))

## Ссылки на библейский текст:

* [Быт. 21:22-24](rc://ru/tn/help/gen/21/22)
* [Быт. 24:1-4](rc://ru/tn/help/gen/24/01)
* [Быт. 31:51-53](rc://ru/tn/help/gen/31/51)
* [Быт. 47:29-31](rc://ru/tn/help/gen/47/29)
* [Лк. 1:72-75](rc://ru/tn/help/luk/01/72)
* [Мк. 6:26-29](rc://ru/tn/help/mrk/06/26)
* [Мф. 5:36-37](rc://ru/tn/help/mat/05/36)
* [Мф. 14:6-7](rc://ru/tn/help/mat/14/06)
* [Мф. 26:71-72](rc://ru/tn/help/mat/26/71)

## Данные о слове:

* Номера Стронга: H422, H423, H3027, H5375, H7621, H7650, G332, G3660, G3727, G3728
